var Segment3D_8h =
[
    [ "Segment3D", "classIMP_1_1algebra_1_1Segment3D.html", "classIMP_1_1algebra_1_1Segment3D" ],
    [ "Segment3Ds", "Segment3D_8h.html#ad59d5651e70a80bfa05f347458e40417", null ],
    [ "get_bounding_box", "Segment3D_8h.html#a0891113bb96a70f9d9d474cbf2089b99", null ],
    [ "get_distance", "Segment3D_8h.html#a7f7687e40a5b27f12babf9730ff8d80c", null ],
    [ "get_distance", "Segment3D_8h.html#a27ea6a618c778638a2a0198aeb9fbd7c", null ],
    [ "get_relative_projection_on_segment", "Segment3D_8h.html#ac5577591de549991f08c38744447c953", null ],
    [ "get_segment_3d_geometry", "Segment3D_8h.html#ac9d72dee0ff175cd772bad26f47e463d", null ],
    [ "set_segment_3d_geometry", "Segment3D_8h.html#ad4acc0a53f732829a51ec021d4bb604d", null ]
];